Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2019-01-23 06:15:43 +0300
committerCampbell Barton <ideasman42@gmail.com>2019-01-23 06:16:03 +0300
commit2e4f1b592f7d1b63ec012528997fab64f16c0416 (patch)
treee53da8d758e3f3454afd27064d2382260653e210 /source/blender/gpu/GPU_texture.h
parent14d947dcadea7c9debe6c8a078a571eba6cb828c (diff)
Cleanup: use eGPU prefix for GPU enum types
Diffstat (limited to 'source/blender/gpu/GPU_texture.h')
-rw-r--r--source/blender/gpu/GPU_texture.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/source/blender/gpu/GPU_texture.h b/source/blender/gpu/GPU_texture.h
index 7a10c2f4854..828673390a4 100644
--- a/source/blender/gpu/GPU_texture.h
+++ b/source/blender/gpu/GPU_texture.h
@@ -63,7 +63,7 @@ typedef struct GPUTexture GPUTexture;
* are not supported by renderbuffers. All of the following formats
* are part of the OpenGL 3.3 core
* specification. */
-typedef enum GPUTextureFormat {
+typedef enum eGPUTextureFormat {
/* Formats texture & renderbuffer */
GPU_RGBA8UI,
GPU_RGBA8I,
@@ -142,57 +142,57 @@ typedef enum GPUTextureFormat {
GPU_DEPTH_COMPONENT32F,
GPU_DEPTH_COMPONENT24,
GPU_DEPTH_COMPONENT16,
-} GPUTextureFormat;
+} eGPUTextureFormat;
-typedef enum GPUDataFormat {
+typedef enum eGPUDataFormat {
GPU_DATA_FLOAT,
GPU_DATA_INT,
GPU_DATA_UNSIGNED_INT,
GPU_DATA_UNSIGNED_BYTE,
GPU_DATA_UNSIGNED_INT_24_8,
GPU_DATA_10_11_11_REV,
-} GPUDataFormat;
+} eGPUDataFormat;
unsigned int GPU_texture_memory_usage_get(void);
/* TODO make it static function again. (create function with GPUDataFormat exposed) */
GPUTexture *GPU_texture_create_nD(
int w, int h, int d, int n, const void *pixels,
- GPUTextureFormat tex_format, GPUDataFormat gpu_data_format, int samples,
+ eGPUTextureFormat tex_format, eGPUDataFormat gpu_data_format, int samples,
const bool can_rescale, char err_out[256]);
GPUTexture *GPU_texture_create_1D(
- int w, GPUTextureFormat data_type, const float *pixels, char err_out[256]);
+ int w, eGPUTextureFormat data_type, const float *pixels, char err_out[256]);
GPUTexture *GPU_texture_create_1D_array(
- int w, int h, GPUTextureFormat data_type, const float *pixels, char err_out[256]);
+ int w, int h, eGPUTextureFormat data_type, const float *pixels, char err_out[256]);
GPUTexture *GPU_texture_create_2D(
- int w, int h, GPUTextureFormat data_type, const float *pixels, char err_out[256]);
+ int w, int h, eGPUTextureFormat data_type, const float *pixels, char err_out[256]);
GPUTexture *GPU_texture_create_2D_multisample(
- int w, int h, GPUTextureFormat data_type, const float *pixels, int samples, char err_out[256]);
+ int w, int h, eGPUTextureFormat data_type, const float *pixels, int samples, char err_out[256]);
GPUTexture *GPU_texture_create_2D_array(
- int w, int h, int d, GPUTextureFormat data_type, const float *pixels, char err_out[256]);
+ int w, int h, int d, eGPUTextureFormat data_type, const float *pixels, char err_out[256]);
GPUTexture *GPU_texture_create_3D(
- int w, int h, int d, GPUTextureFormat data_type, const float *pixels, char err_out[256]);
+ int w, int h, int d, eGPUTextureFormat data_type, const float *pixels, char err_out[256]);
GPUTexture *GPU_texture_create_cube(
- int w, GPUTextureFormat data_type, const float *pixels, char err_out[256]);
+ int w, eGPUTextureFormat data_type, const float *pixels, char err_out[256]);
GPUTexture *GPU_texture_create_from_vertbuf(
struct GPUVertBuf *vert);
GPUTexture *GPU_texture_create_buffer(
- GPUTextureFormat data_type, const uint buffer);
+ eGPUTextureFormat data_type, const uint buffer);
GPUTexture *GPU_texture_from_bindcode(int textarget, int bindcode);
GPUTexture *GPU_texture_from_blender(
struct Image *ima, struct ImageUser *iuser, int textarget, bool is_data, double time);
GPUTexture *GPU_texture_from_preview(struct PreviewImage *prv, int mipmap);
-void GPU_texture_add_mipmap(GPUTexture *tex, GPUDataFormat gpu_data_format, int miplvl, const void *pixels);
+void GPU_texture_add_mipmap(GPUTexture *tex, eGPUDataFormat gpu_data_format, int miplvl, const void *pixels);
-void GPU_texture_update(GPUTexture *tex, GPUDataFormat data_format, const void *pixels);
+void GPU_texture_update(GPUTexture *tex, eGPUDataFormat data_format, const void *pixels);
void GPU_texture_update_sub(
- GPUTexture *tex, GPUDataFormat gpu_data_format, const void *pixels,
+ GPUTexture *tex, eGPUDataFormat gpu_data_format, const void *pixels,
int offset_x, int offset_y, int offset_z, int width, int height, int depth);
-void *GPU_texture_read(GPUTexture *tex, GPUDataFormat gpu_data_format, int miplvl);
+void *GPU_texture_read(GPUTexture *tex, eGPUDataFormat gpu_data_format, int miplvl);
void GPU_invalid_tex_init(void);
void GPU_invalid_tex_bind(int mode);
@@ -210,7 +210,7 @@ void GPU_texture_compare_mode(GPUTexture *tex, bool use_compare);
void GPU_texture_filter_mode(GPUTexture *tex, bool use_filter);
void GPU_texture_mipmap_mode(GPUTexture *tex, bool use_mipmap, bool use_filter);
void GPU_texture_wrap_mode(GPUTexture *tex, bool use_repeat);
-void GPU_texture_filters(GPUTexture *tex, GPUFilterFunction min_filter, GPUFilterFunction mag_filter);
+void GPU_texture_filters(GPUTexture *tex, eGPUFilterFunction min_filter, eGPUFilterFunction mag_filter);
void GPU_texture_attach_framebuffer(GPUTexture *tex, struct GPUFrameBuffer *fb, int attachment);
int GPU_texture_detach_framebuffer(GPUTexture *tex, struct GPUFrameBuffer *fb);
@@ -219,7 +219,7 @@ int GPU_texture_target(const GPUTexture *tex);
int GPU_texture_width(const GPUTexture *tex);
int GPU_texture_height(const GPUTexture *tex);
int GPU_texture_layers(const GPUTexture *tex);
-GPUTextureFormat GPU_texture_format(const GPUTexture *tex);
+eGPUTextureFormat GPU_texture_format(const GPUTexture *tex);
int GPU_texture_samples(const GPUTexture *tex);
bool GPU_texture_cube(const GPUTexture *tex);
bool GPU_texture_depth(const GPUTexture *tex);
@@ -142,57 +142,57 @@ typedef enum GPUTextureFormat {
unsigned int GPU_texture_memory_usage_get(void);
-/* TODO make it static function again. (create function with GPUDataFormat exposed) */
+/* TODO make it static function again. (create function with eGPUDataFormat exposed) */
GPUTexture *GPU_texture_create_nD(
int w, int h, int d, int n, const void *pixels,